# Config file for the metview package
# Defines the following variables:
#
#  METVIEW_INCLUDE_DIRS   - include directories
#  METVIEW_DEFINITIONS    - preprocessor definitions
#  METVIEW_LIBRARIES      - libraries to link against
#  METVIEW_FEATURES       - list of enabled features
#  METVIEW_VERSION        - version of the package
#  METVIEW_GIT_SHA1       - Git revision of the package
#  METVIEW_GIT_SHA1_SHORT - short Git revision of the package
#
# Also defines metview third-party library dependencies:
#  METVIEW_TPLS             - package names of  third-party library dependencies
#  METVIEW_TPL_INCLUDE_DIRS - include directories
#  METVIEW_TPL_DEFINITIONS  - preprocessor definitions
#  METVIEW_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(METVIEW_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( METVIEW_SELF_INCLUDE_DIRS "${METVIEW_CMAKE_DIR}/../../../include" )
set( METVIEW_SELF_DEFINITIONS  "" )
set( METVIEW_SELF_LIBRARIES    "MvMars;macro_api_f90;Util;Metview;MvNetCDF;FTimeUtil;MvQtUtil;MvQtGui" )

set( METVIEW_TPLS              "grib_api;NetCDF" )
set( METVIEW_TPL_INCLUDE_DIRS  "/usr/lib/include;/usr/include;/usr/include;/usr/include;/usr/include/hdf5/serial;/usr/include;/usr/include/python2.7;/usr/include/x86_64-linux-gnu/python2.7;/usr/include;/usr/include;/usr/include/hdf5/serial" )
set( METVIEW_TPL_DEFINITIONS   "" )
set( METVIEW_TPL_LIBRARIES     "grib_api;grib_api_f77;grib_api_f90;/usr/lib/x86_64-linux-gnu/libpng.so;/usr/lib/x86_64-linux-gnu/libz.so;debug;optimized;/usr/lib/x86_64-linux-gnu/libnetcdf.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libsz.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/libaec.so;-L/usr/lib/python2.7/config-x86_64-linux-gnu -L/usr/lib -lpython2.7 -lpthread -ldl  -lutil -lm  -Xlinker -export-dynamic -Wl,-O1 -Wl,-Bsymbolic-functions;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/libopenjpeg.so;debug;optimized;/usr/lib/x86_64-linux-gnu/libnetcdf_c++.so;/usr/lib/x86_64-linux-gnu/libnetcdf.so;/usr/lib/x86_64-linux-gnu/hdf5/serial/lib/libhdf5.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libsz.so;/usr/lib/x86_64-linux-gnu/libz.so;/usr/lib/x86_64-linux-gnu/libdl.so;/usr/lib/x86_64-linux-gnu/libm.so" )

set( METVIEW_VERSION           "4.6.5" )
set( METVIEW_GIT_SHA1          "" )
set( METVIEW_GIT_SHA1_SHORT    "" )

### export include paths as absolute paths

set( METVIEW_INCLUDE_DIRS "" )
foreach( path ${METVIEW_SELF_INCLUDE_DIRS} )
  get_filename_component( abspath ${path} ABSOLUTE )
  list( APPEND METVIEW_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND METVIEW_INCLUDE_DIRS ${METVIEW_TPL_INCLUDE_DIRS} )

### export definitions

set( METVIEW_DEFINITIONS      ${METVIEW_SELF_DEFINITIONS} ${METVIEW_TPL_DEFINITIONS} )

### export list of all libraries

set( METVIEW_LIBRARIES        ${METVIEW_SELF_LIBRARIES}   ${METVIEW_TPL_LIBRARIES}   )

### export the features provided by the package

set( METVIEW_FEATURES    "TESTS" )
foreach( _f ${METVIEW_FEATURES} )
  set( METVIEW_HAVE_${_f} 1 )
endforeach()

# Has this configuration been exported from a build tree?
set( METVIEW_IS_BUILD_DIR_EXPORT OFF )

if( EXISTS ${METVIEW_CMAKE_DIR}/metview-import.cmake )
  set( METVIEW_IMPORT_FILE "${METVIEW_CMAKE_DIR}/metview-import.cmake" )
  include( ${METVIEW_IMPORT_FILE} )
endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# insert definitions for IMPORTED targets

if( NOT metview_BINARY_DIR )

  if( METVIEW_IS_BUILD_DIR_EXPORT )
    include( "/build/metview-7qTsm6/metview-4.6.5/debian/build/metview-targets.cmake" OPTIONAL )
  else()
    include( "${METVIEW_CMAKE_DIR}/metview-targets.cmake" )
  endif()

endif()

# publish this file as imported

set( METVIEW_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( METVIEW_IMPORT_FILE )

# set metview_BASE_DIR for final installations or build directories

if( NOT metview )
  if( METVIEW_IS_BUILD_DIR_EXPORT )
    set( metview_BASE_DIR /build/metview-7qTsm6/metview-4.6.5/debian/build )
  else()
    get_filename_component( abspath ${CMAKE_CURRENT_LIST_DIR}/../../.. ABSOLUTE )
    set( metview_BASE_DIR ${abspath} )
  endif()
endif()
